@@ -15,7 +15,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: EphyBrowser.cpp,v 1.53.4.7 2004/11/13 19:56:49 chpe Exp $
+ *  $Id: EphyBrowser.cpp,v 1.53.4.12 2004/11/19 20:15:59 chpe Exp $
  */
 
 #include "mozilla-config.h"
@@ -65,6 +65,8 @@
 #include "nsIDOMNode.h"
 #include "nsIDOMElement.h"
 #include "nsIDOMWindow2.h"
+#include "nsIDOMDocumentView.h"
+#include "nsIDOMAbstractView.h"
 #define MOZILLA_STRICT_API
 #include "nsEmbedString.h"
 #undef MOZILLA_STRICT_API
@@ -72,6 +74,7 @@
 #include "nsIChannel.h"
 #include "nsIScriptSecurityManager.h"
 #include "nsIServiceManager.h"
+#include "nsIInterfaceRequestor.h"
 
 #ifdef ALLOW_PRIVATE_API
 /* not frozen yet */
@@ -82,6 +85,11 @@
 #ifdef HAVE_MOZILLA_PSM
 /* not sure about this one: */
 #include <nsITransportSecurityInfo.h>
+/* these are in pipnss/, are they really private? */
+#include <nsISSLStatus.h>
+#include <nsISSLStatusProvider.h>
+#include <nsIX509Cert.h>
+#include <nsICertificateDialogs.h>
 #endif
 #endif
 
@@ -112,7 +120,7 @@ EphyEventListener::~EphyEventListener()
 NS_IMPL_ISUPPORTS1(EphyEventListener, nsIDOMEventListener)
 
 nsresult
-EphyEventListener::Init(EphyEmbed *aOwner)
+EphyEventListener::Init (EphyBrowser *aOwner)
 {
 	mOwner = aOwner;
 	return NS_OK;
@@ -155,6 +163,23 @@ EphyFaviconEventListener::HandleEvent(nsIDOMEvent* aDOMEvent)
 		node->GetOwnerDocument(getter_AddRefs(domDoc));
 		NS_ENSURE_TRUE (domDoc, NS_ERROR_FAILURE);
 
+		nsCOMPtr<nsIDOMDocumentView> docView (do_QueryInterface (domDoc));
+		NS_ENSURE_TRUE (docView, NS_ERROR_FAILURE);
+
+		nsCOMPtr<nsIDOMAbstractView> abstractView;
+		docView->GetDefaultView (getter_AddRefs (abstractView));
+
+		nsCOMPtr<nsIDOMWindow> domWin (do_QueryInterface (abstractView));
+		NS_ENSURE_TRUE (domWin, NS_ERROR_FAILURE);
+
+		nsCOMPtr<nsIDOMWindow> topDomWin;
+		domWin->GetTop (getter_AddRefs (topDomWin));
+
+		nsCOMPtr<nsISupports> domWinAsISupports (do_QueryInterface (domWin));
+		nsCOMPtr<nsISupports> topDomWinAsISupports (do_QueryInterface (topDomWin));
+		/* disallow subframes to set favicon */
+		if (domWinAsISupports != topDomWinAsISupports) return NS_OK;
+
 		nsCOMPtr<nsIDOM3Document> doc = do_QueryInterface (domDoc);
 		NS_ENSURE_TRUE (doc, NS_ERROR_FAILURE);
 
@@ -213,16 +238,14 @@ EphyFaviconEventListener::HandleEvent(nsIDOMEvent* aDOMEvent)
 		PRBool shouldLoad = PR_FALSE;
 		rv = policy->ShouldLoad (nsIContentPolicy::IMAGE,
 					 favUri, eventTarget,
-					 nsnull /* FIXME: DOM window*/,
+					 domWin,
 					 &shouldLoad);
 		NS_ENSURE_SUCCESS (rv, NS_ERROR_FAILURE);
 		if (!shouldLoad) return NS_OK;
 #endif
 
 		/* ok, we accept this as a valid favicon for this site */
-		char *url = g_strdup (faviconUrl.get());
-		g_signal_emit_by_name (mOwner, "ge_favicon", url);
-		g_free (url);
+		g_signal_emit_by_name (mOwner->mEmbed, "ge_favicon", faviconUrl.get());
 	}
 
 	return NS_OK;
@@ -231,8 +254,6 @@ EphyFaviconEventListener::HandleEvent(nsIDOMEvent* aDOMEvent)
 NS_IMETHODIMP
 EphyPopupBlockEventListener::HandleEvent (nsIDOMEvent * aDOMEvent)
 {
-	NS_ENSURE_TRUE (mOwner != NULL, NS_ERROR_FAILURE);
-
 	nsCOMPtr<nsIDOMPopupBlockedEvent> popupEvent =
 		do_QueryInterface (aDOMEvent);
 	NS_ENSURE_TRUE (popupEvent, NS_ERROR_FAILURE);
@@ -255,7 +276,7 @@ EphyPopupBlockEventListener::HandleEvent (nsIDOMEvent * aDOMEvent)
 			   NS_CSTRING_ENCODING_UTF8,
 			   popupWindowFeaturesString);
 
-	g_signal_emit_by_name(mOwner, "ge_popup_blocked",
+	g_signal_emit_by_name(mOwner->mEmbed, "ge_popup_blocked",
 			      popupWindowURIString.get(),
 			      popupWindowFeaturesString.get());
 
@@ -288,7 +309,7 @@ EphyModalAlertEventListener::HandleEvent (nsIDOMEvent * aDOMEvent)
 	if (strcmp (cType.get(), "DOMWillOpenModalDialog") == 0)
 	{
 		gboolean retval = FALSE;
-		g_signal_emit_by_name (mOwner, "ge-modal-alert", &retval);
+		g_signal_emit_by_name (mOwner->mEmbed, "ge-modal-alert", &retval);
 
 		/* suppress alert */
 		if (retval)
@@ -299,7 +320,7 @@ EphyModalAlertEventListener::HandleEvent (nsIDOMEvent * aDOMEvent)
 	}
 	else if (strcmp (cType.get(), "DOMModalDialogClosed") == 0)
 	{
-		g_signal_emit_by_name (mOwner, "ge-modal-alert-closed");
+		g_signal_emit_by_name (mOwner->mEmbed, "ge-modal-alert-closed");
 	}
 #endif
 
@@ -324,6 +345,8 @@ nsresult EphyBrowser::Init (GtkMozEmbed *mozembed)
 {
 	if (mInitialized) return NS_OK;
 
+	mEmbed = GTK_WIDGET (mozembed);
+
 	gtk_moz_embed_get_nsIWebBrowser (mozembed,
 					 getter_AddRefs(mWebBrowser));
 	NS_ENSURE_TRUE (mWebBrowser, NS_ERROR_FAILURE);
@@ -340,27 +363,40 @@ nsresult EphyBrowser::Init (GtkMozEmbed *mozembed)
 	mFaviconEventListener = new EphyFaviconEventListener();
 	if (!mFaviconEventListener) return NS_ERROR_OUT_OF_MEMORY;
 
-	rv = mFaviconEventListener->Init (EPHY_EMBED (mozembed));
+	rv = mFaviconEventListener->Init (this);
 	NS_ENSURE_SUCCESS (rv, NS_ERROR_FAILURE);
 
 	mPopupBlockEventListener = new EphyPopupBlockEventListener();
 	if (!mPopupBlockEventListener) return NS_ERROR_OUT_OF_MEMORY;
 
-	rv = mPopupBlockEventListener->Init (EPHY_EMBED (mozembed));
+	rv = mPopupBlockEventListener->Init (this);
 	NS_ENSURE_SUCCESS (rv, NS_ERROR_FAILURE);
 
 	mModalAlertListener = new EphyModalAlertEventListener ();
 	if (!mModalAlertListener) return NS_ERROR_OUT_OF_MEMORY;
 
-	rv = mModalAlertListener->Init (EPHY_EMBED (mozembed));
+	rv = mModalAlertListener->Init (this);
 	NS_ENSURE_SUCCESS (rv, NS_ERROR_FAILURE);
 
  	rv = GetListener();
 	NS_ENSURE_SUCCESS (rv, NS_ERROR_FAILURE);
 
+	rv = AttachListeners();
+	NS_ENSURE_SUCCESS (rv, NS_ERROR_FAILURE);
+
+#ifdef HAVE_MOZILLA_PSM
+	/* FIXME: mozilla sucks! nsWebBrowser already has an instance of this,
+	 * but we cannot get to it!
+	 * See https://bugzilla.mozilla.org/show_bug.cgi?id=94974
+	 */
+	mSecurityInfo = do_CreateInstance(NS_SECURE_BROWSER_UI_CONTRACTID, &rv);
+	NS_ENSURE_TRUE (NS_SUCCEEDED (rv) && mSecurityInfo, NS_ERROR_FAILURE);
+	mSecurityInfo->Init (mDOMWindow);
+#endif
+
 	mInitialized = PR_TRUE;
 
-	return AttachListeners();
+	return NS_OK;
 }
 
 nsresult
@@ -510,6 +546,7 @@ nsresult EphyBrowser::Destroy ()
       	mWebBrowser = nsnull;
 	mDOMWindow = nsnull;
 	mEventTarget = nsnull;
+	mEmbed = nsnull;
 
 	mInitialized = PR_FALSE;
 
@@ -1045,16 +1082,21 @@ nsresult EphyBrowser::GetHasModifiedForms (PRBool *modified)
 }
 
 nsresult
-EphyBrowser::SetSecurityInfo (nsIRequest *aRequest)
+EphyBrowser::GetSecurityInfo (PRUint32 *aState, nsACString &aDescription)
 {
 #ifdef HAVE_MOZILLA_PSM
-	/* clear previous security info */
-	mSecurityInfo = nsnull;
+	NS_ENSURE_TRUE (mSecurityInfo, NS_ERROR_FAILURE);
 
-	nsCOMPtr<nsIChannel> channel (do_QueryInterface (aRequest));
-	NS_ENSURE_TRUE (channel, NS_ERROR_FAILURE);
+	nsresult rv;
+	rv = mSecurityInfo->GetState (aState);
+	NS_ENSURE_SUCCESS (rv, NS_ERROR_FAILURE);
 
-	channel->GetSecurityInfo (getter_AddRefs (mSecurityInfo));
+	nsEmbedString tooltip;
+	rv = mSecurityInfo->GetTooltipText (tooltip);
+	NS_ENSURE_SUCCESS (rv, NS_ERROR_FAILURE);
+
+	NS_UTF16ToCString (tooltip,
+			   NS_CSTRING_ENCODING_UTF8, aDescription);
 
 	return NS_OK;
 #else
@@ -1063,25 +1105,29 @@ EphyBrowser::SetSecurityInfo (nsIRequest *aRequest)
 }
 
 nsresult
-EphyBrowser::GetSecurityDescription (nsACString &aDescription)
+EphyBrowser::ShowCertificate ()
 {
 #ifdef HAVE_MOZILLA_PSM
-	if (!mSecurityInfo) return NS_ERROR_FAILURE;
+	NS_ENSURE_TRUE (mSecurityInfo, NS_ERROR_FAILURE);
 
-	nsCOMPtr<nsITransportSecurityInfo> tsInfo (do_QueryInterface (mSecurityInfo));
-	NS_ENSURE_TRUE (tsInfo, NS_ERROR_FAILURE);
+	nsCOMPtr<nsISSLStatusProvider> statusProvider (do_QueryInterface (mSecurityInfo));
+	NS_ENSURE_TRUE (statusProvider, NS_ERROR_FAILURE);
 
-	nsresult rv;
-	PRUnichar *tooltip = nsnull;
-	rv = tsInfo->GetShortSecurityDescription (&tooltip);
-	NS_ENSURE_TRUE (NS_SUCCEEDED (rv) && tooltip, NS_ERROR_FAILURE);
+	nsCOMPtr<nsISSLStatus> SSLStatus;
+	statusProvider->GetSSLStatus (getter_AddRefs (SSLStatus));
+	NS_ENSURE_TRUE (SSLStatus, NS_ERROR_FAILURE);
 
-	NS_UTF16ToCString (nsEmbedString (tooltip),
-			   NS_CSTRING_ENCODING_UTF8, aDescription);
-	if (tooltip) nsMemory::Free (tooltip);
+	nsCOMPtr<nsIX509Cert> serverCert;
+	SSLStatus->GetServerCert (getter_AddRefs (serverCert));
+	NS_ENSURE_TRUE (serverCert, NS_ERROR_FAILURE);
 
-	return NS_OK;
+	nsCOMPtr<nsICertificateDialogs> certDialogs (do_GetService (NS_CERTIFICATEDIALOGS_CONTRACTID));
+	NS_ENSURE_TRUE (certDialogs, NS_ERROR_FAILURE);
+
+	nsCOMPtr<nsIInterfaceRequestor> requestor(do_QueryInterface (mDOMWindow));
+
+	return certDialogs->ViewCert (requestor, serverCert);
 #else
-	return NS_ERROR_NOT_IMPLEMENTED;
+	return NS_OK;
 #endif
 }
