@@ -17,7 +17,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: EventContext.cpp,v 1.39.4.1 2004/09/26 16:48:26 chpe Exp $
+ *  $Id: EventContext.cpp,v 1.39.4.5 2004/11/22 22:12:36 chpe Exp $
  */
 
 #include "mozilla-config.h"
@@ -33,7 +33,9 @@
 
 #include <nsIInterfaceRequestor.h>
 #include <nsIServiceManager.h>
+#define MOZILLA_STRICT_API
 #include <nsEmbedString.h>
+#undef MOZILLA_STRICT_API
 #include <nsIDOMEventTarget.h>
 #include <nsIDOMHTMLInputElement.h>
 #include <nsIDOMHTMLObjectElement.h>
@@ -476,7 +478,7 @@ nsresult EventContext::GetEventContext (nsIDOMEventTarget *EventTarget,
 				info->context = EMBED_CONTEXT_NONE;
 				return NS_OK;
 			}
-			if (g_ascii_strcasecmp (tag.get(), "area") == 0)
+			else if (g_ascii_strcasecmp (tag.get(), "area") == 0)
 			{
 				info->context |= EMBED_CONTEXT_LINK;
 				nsCOMPtr <nsIDOMHTMLAreaElement> area =
@@ -514,8 +516,6 @@ nsresult EventContext::GetEventContext (nsIDOMEventTarget *EventTarget,
                                                 return NS_ERROR_FAILURE;
 					SetStringProperty ("background_image",
 						           bgimg.get());
-					if (NS_FAILED (rv))
-						return NS_ERROR_FAILURE;
 
 					has_background = PR_TRUE;
 				}
@@ -577,7 +577,7 @@ nsresult EventContext::GetCSSBackground (nsIDOMNode *node, nsAString& url)
 nsresult EventContext::GetMouseEventInfo (nsIDOMMouseEvent *aMouseEvent, MozillaEmbedEvent *info)
 {
 	/* FIXME: casting 32-bit guint* to PRUint16* below will break on big-endian */
-	PRUint16 btn;
+	PRUint16 btn = (PRUint16) -1;
 	aMouseEvent->GetButton (&btn);
 
 	switch (btn)
@@ -803,14 +803,14 @@ nsresult EventContext::CheckLinkScheme (const nsAString &link)
 	rv = uri->GetScheme (scheme);
 	if (NS_FAILED (rv)) return NS_ERROR_FAILURE;
 
-	if (g_ascii_strcasecmp (scheme.get(), "http") ||
-	    g_ascii_strcasecmp (scheme.get(), "https") ||
-	    g_ascii_strcasecmp (scheme.get(), "ftp") ||
-	    g_ascii_strcasecmp (scheme.get(), "file") ||
-	    g_ascii_strcasecmp (scheme.get(), "data") ||
-	    g_ascii_strcasecmp (scheme.get(), "resource") ||
-	    g_ascii_strcasecmp (scheme.get(), "about") ||
-	    g_ascii_strcasecmp (scheme.get(), "gopher"))
+	if (g_ascii_strcasecmp (scheme.get(), "http") == 0 ||
+	    g_ascii_strcasecmp (scheme.get(), "https") == 0 ||
+	    g_ascii_strcasecmp (scheme.get(), "ftp") == 0 ||
+	    g_ascii_strcasecmp (scheme.get(), "file") == 0 ||
+	    g_ascii_strcasecmp (scheme.get(), "data") == 0 ||
+	    g_ascii_strcasecmp (scheme.get(), "resource") == 0 ||
+	    g_ascii_strcasecmp (scheme.get(), "about") == 0 ||
+	    g_ascii_strcasecmp (scheme.get(), "gopher") == 0)
 	{
 		SetIntProperty ("link-has-web-scheme", TRUE);
 	}
