@@ -38,7 +38,7 @@
  *
  * ***** END LICENSE BLOCK *****
  *
- * $Id: MozDownload.cpp,v 1.47.4.4 2004/11/13 19:56:49 chpe Exp $
+ * $Id: MozDownload.cpp,v 1.47.4.5 2004/12/19 14:37:12 chpe Exp $
  */
 
 #include "mozilla-config.h"
@@ -195,6 +195,22 @@ MozDownload::GetPercentComplete(PRInt32 *aPercentComplete)
  	return NS_OK;
 }
 
+#ifdef MOZ_NSIDOWNLOAD_GETSIZE
+/* readonly attribute PRUint64 amountTransferred; */
+NS_IMETHODIMP
+MozDownload::GetAmountTransferred(PRUint64 *aAmountTransferred)
+{
+    return NS_ERROR_NOT_IMPLEMENTED;
+}
+
+/* readonly attribute PRUint64 size; */
+NS_IMETHODIMP
+MozDownload::GetSize(PRUint64 *aSize)
+{
+    return NS_ERROR_NOT_IMPLEMENTED;
+}
+#endif /* MOZ_NSIDOWNLOAD_GETSIZE */
+
 NS_IMETHODIMP
 MozDownload::GetTotalProgress(PRInt32 *aTotalProgress)
 {
