@@ -16,30 +16,34 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: MozRegisterComponents.cpp,v 1.26 2004/05/01 20:46:59 chpe Exp $
+ *  $Id: MozRegisterComponents.cpp,v 1.28.4.1 2004/11/19 20:15:25 chpe Exp $
  */
 
+#include "mozilla-config.h"
+
 #ifdef HAVE_CONFIG_H
 #include "config.h"
 #endif
 
 #include "ContentHandler.h"
-#include "FilePicker.h"
 #include "GlobalHistory.h"
 #include "PrintingPromptService.h"
 #include "MozDownload.h"
 #include "EphyAboutRedirector.h"
 #include "EphyContentPolicy.h"
 
+#ifdef ENABLE_FILEPICKER
+#include "FilePicker.h"
+#endif
+
 #ifdef HAVE_MOZILLA_PSM
 #include "GtkNSSClientAuthDialogs.h"
 #include "GtkNSSDialogs.h"
 #include "GtkNSSKeyPairDialogs.h"
 #endif
 
-#if MOZILLA_SNAPSHOT > 13
+#include <nsMemory.h>
 #include <nsDocShellCID.h>
-#endif
 #include <nsIGenericFactory.h>
 #include <nsIComponentRegistrar.h>
 #include <nsICategoryManager.h>
@@ -50,13 +54,16 @@
 #include <glib/gmessages.h>
 
 NS_GENERIC_FACTORY_CONSTRUCTOR(EphyAboutRedirector)
-NS_GENERIC_FACTORY_CONSTRUCTOR(MozDownload)	
-NS_GENERIC_FACTORY_CONSTRUCTOR(GFilePicker)
+NS_GENERIC_FACTORY_CONSTRUCTOR(MozDownload)
 NS_GENERIC_FACTORY_CONSTRUCTOR(GContentHandler)
 NS_GENERIC_FACTORY_CONSTRUCTOR(MozGlobalHistory)
 NS_GENERIC_FACTORY_CONSTRUCTOR(GPrintingPromptService)
 NS_GENERIC_FACTORY_CONSTRUCTOR(EphyContentPolicy)
 
+#ifdef ENABLE_FILEPICKER
+NS_GENERIC_FACTORY_CONSTRUCTOR(GFilePicker)
+#endif
+
 #ifdef HAVE_MOZILLA_PSM
 NS_GENERIC_FACTORY_CONSTRUCTOR(GtkNSSClientAuthDialogs)
 NS_GENERIC_FACTORY_CONSTRUCTOR(GtkNSSDialogs)
@@ -72,11 +79,12 @@ RegisterContentPolicy(nsIComponentManager *aCompMgr, nsIFile *aPath,
 		do_GetService(NS_CATEGORYMANAGER_CONTRACTID);
 	NS_ENSURE_TRUE (cm, NS_ERROR_FAILURE);
 
-	nsXPIDLCString oldval;
+	char *oldval;
 	return cm->AddCategoryEntry("content-policy",
 				    EPHY_CONTENT_POLICY_CONTRACTID,
 				    EPHY_CONTENT_POLICY_CONTRACTID,
-				    PR_TRUE, PR_TRUE, getter_Copies (oldval));
+				    PR_TRUE, PR_TRUE, &oldval);
+	nsMemory::Free (oldval);
 }
 
 static const nsModuleComponentInfo sAppComps[] = {
@@ -86,12 +94,14 @@ static const nsModuleComponentInfo sAppComps[] = {
 		NS_DOWNLOAD_CONTRACTID,
 		MozDownloadConstructor
 	},
+#ifdef ENABLE_FILEPICKER
 	{
 		G_FILEPICKER_CLASSNAME,
 		G_FILEPICKER_CID,
 		G_FILEPICKER_CONTRACTID,
 		GFilePickerConstructor
 	},
+#endif
 #ifdef HAVE_MOZILLA_PSM
 	{
 		GTK_NSSCLIENTAUTHDIALOGS_CLASSNAME,
@@ -127,11 +137,7 @@ static const nsModuleComponentInfo sAppComps[] = {
 	{
 		EPHY_GLOBALHISTORY_CLASSNAME,
 		EPHY_GLOBALHISTORY_CID,
-#if MOZILLA_SNAPSHOT > 13
 		NS_GLOBALHISTORY2_CONTRACTID,
-#else
-		NS_GLOBALHISTORY_CONTRACTID,
-#endif
 		MozGlobalHistoryConstructor
 	},
 	{
@@ -220,5 +226,3 @@ mozilla_register_components (void)
 
 	return ret;
 }
-
-
