@@ -16,7 +16,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: ephy-dialog.c,v 1.37.4.1 2004/09/22 18:12:03 chpe Exp $
+ *  $Id: ephy-dialog.c,v 1.37.4.5 2004/10/23 20:51:23 chpe Exp $
  */
 
 #ifdef HAVE_CONFIG_H
@@ -587,16 +587,10 @@ set_combo_box_from_value (PropertyInfo *info, const  GValue *value)
 		}
 		else
 		{
-			char *v;
-
-			gtk_combo_box_set_active (GTK_COMBO_BOX (info->widget), -1);
-
-			v = g_strdup_value_contents (value);
-			g_warning ("Value '%s' not found in model for combo %s\n", v, info->id);
-			g_free (v);
+			gtk_combo_box_set_active (GTK_COMBO_BOX (info->widget), 0);
 		}
 
-		info->sane_state = found;
+		info->sane_state = TRUE;
 	}
 	else if (info->data_type == G_TYPE_INT)
 	{
@@ -1018,7 +1012,7 @@ setup_default_size (EphyDialog *dialog)
 				       dialog->priv->name,
 				       dialog->priv->default_width,
 				       dialog->priv->default_height,
-				       flags);
+				       FALSE, flags);
 
 		dialog->priv->has_default_size = TRUE;
 	}
@@ -1304,6 +1298,8 @@ ephy_dialog_dispose (GObject *object)
 		gtk_widget_destroy (dialog->priv->dialog);
 		dialog->priv->dialog = NULL;
 	}
+
+	parent_class->dispose (object);
 }
 
 static void
