@@ -15,7 +15,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: ephy-tree-model-node.c,v 1.17 2004/07/23 02:25:04 marco Exp $
+ *  $Id: ephy-tree-model-node.c,v 1.18 2004/08/18 15:44:44 chpe Exp $
  */
 
 #ifdef HAVE_CONFIG_H
@@ -421,7 +421,7 @@ ephy_tree_model_node_get_value (GtkTreeModel *tree_model,
 	}
 }
 
-static guint
+static GtkTreeModelFlags
 ephy_tree_model_node_get_flags (GtkTreeModel *tree_model)
 {
 	return GTK_TREE_MODEL_ITERS_PERSIST | GTK_TREE_MODEL_LIST_ONLY;
