@@ -17,7 +17,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: ephy-bookmarksbar.c,v 1.9 2004/08/09 18:41:49 chpe Exp $
+ *  $Id: ephy-bookmarksbar.c,v 1.9.4.1 2004/09/27 18:11:40 chpe Exp $
  */
 
 #ifdef HAVE_CONFIG_H
@@ -356,7 +356,7 @@ ephy_bookmarksbar_set_property (GObject *object,
 		case PROP_BOOKMARKS:
 			toolbar->priv->bookmarks = g_value_get_object (value);
 			toolbar->priv->toolbars_model =
-				ephy_bookmarks_get_toolbars_model (toolbar->priv->bookmarks);
+				EGG_TOOLBARS_MODEL (ephy_bookmarks_get_toolbars_model (toolbar->priv->bookmarks));
 			break;
 		case PROP_WINDOW:
 			ephy_bookmarksbar_set_window (toolbar, g_value_get_object (value));
