@@ -15,7 +15,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: ephy-topic-action.c,v 1.52 2004/08/28 11:00:13 chpe Exp $
+ *  $Id: ephy-topic-action.c,v 1.52.4.4 2004/11/07 19:57:03 chpe Exp $
  */
 
 #ifdef HAVE_CONFIG_H
@@ -246,13 +246,15 @@ sort_bookmarks (gconstpointer a, gconstpointer b)
 #define MAX_LENGTH 32
 
 static gboolean
-can_open_in_tabs (EphyTopicAction *action)
+can_open_in_tabs (EphyNode *node)
 {
 	GPtrArray *children;
+	int priority;
 
-	children = ephy_node_get_children (action->priv->topic_node);
+	priority = ephy_node_get_property_int (node, EPHY_NODE_KEYWORD_PROP_PRIORITY);
+	children = ephy_node_get_children (node);
 
-	return (children->len > 1);
+	return (priority != EPHY_NODE_ALL_PRIORITY) && (children->len > 1);
 }
 
 static void
@@ -337,14 +339,20 @@ append_bookmarks_menu (EphyTopicAction *action, GtkWidget *menu, EphyNode *node,
 	}
 }
 
+#define TOPIC_NODE_DATA_KEY	"TopicNode"
+
 static void
-open_in_tabs_activate_cb (GtkWidget *menu, EphyTopicAction *action)
+open_in_tabs_activate_cb (GtkWidget *item, EphyTopicAction *action)
 {
+	EphyNode *node;
 	GList *uri_list = NULL;
 	GPtrArray *children;
 	int i;
 
-	children = ephy_node_get_children (action->priv->topic_node);
+	node = g_object_get_data (G_OBJECT (item), TOPIC_NODE_DATA_KEY);
+	g_return_if_fail (node != NULL);
+
+	children = ephy_node_get_children (node);
 	for (i = 0; i < children->len; i++)
 	{
 		const char *address;
@@ -397,7 +405,7 @@ remove_from_model (GtkWidget *widget)
 	pos = get_item_position (widget, NULL);
 
 	bookmarks = ephy_shell_get_bookmarks (ephy_shell);
-	model = ephy_bookmarks_get_toolbars_model (bookmarks);
+	model = EGG_TOOLBARS_MODEL (ephy_bookmarks_get_toolbars_model (bookmarks));
 
 	egg_toolbars_model_remove_item (model, 0, pos);
 }
@@ -410,7 +418,7 @@ move_in_model (GtkWidget *widget, int direction)
 	int pos, new_pos;
 
 	bookmarks = ephy_shell_get_bookmarks (ephy_shell);
-	model = ephy_bookmarks_get_toolbars_model (bookmarks);
+	model = EGG_TOOLBARS_MODEL (ephy_bookmarks_get_toolbars_model (bookmarks));
 
 	pos = get_item_position (widget, NULL);
 	new_pos = MAX (0, pos + direction);
@@ -437,7 +445,9 @@ move_right_activate_cb (GtkWidget *menu, GtkWidget *proxy)
 }
 
 static GtkWidget *
-add_open_in_tabs_menu (EphyTopicAction *action, GtkWidget *menu)
+add_open_in_tabs_menu (EphyTopicAction *action,
+		       GtkWidget *menu,
+		       EphyNode *node)
 {
 	GtkWidget *item;
 
@@ -445,6 +455,8 @@ add_open_in_tabs_menu (EphyTopicAction *action, GtkWidget *menu)
 	gtk_widget_show (item);
 	gtk_menu_shell_append (GTK_MENU_SHELL (menu), item);
 
+	g_object_set_data (G_OBJECT (item), TOPIC_NODE_DATA_KEY, node);
+
 	g_signal_connect (item, "activate",
 			  G_CALLBACK (open_in_tabs_activate_cb), action);
 
@@ -460,7 +472,7 @@ build_bookmarks_menu (EphyTopicAction *action, EphyNode *node)
 
 	append_bookmarks_menu (action, menu, node, TRUE);
 
-	if (can_open_in_tabs (action))
+	if (can_open_in_tabs (node))
 	{
 		GtkWidget *item;
 
@@ -468,7 +480,7 @@ build_bookmarks_menu (EphyTopicAction *action, EphyNode *node)
 		gtk_widget_show (item);
 		gtk_menu_shell_append (GTK_MENU_SHELL (menu), item);
 
-		add_open_in_tabs_menu (action, menu);
+		add_open_in_tabs_menu (action, menu, node);
 	}
 
 	return menu;
@@ -660,6 +672,8 @@ drag_motion_cb (GtkWidget *widget, GdkEventMotion *event, EphyTopicAction *actio
 		gtk_menu_popdown (GTK_MENU (widget));
 		gtk_drag_begin (button, target_list, GDK_ACTION_MOVE |
 				GDK_ACTION_COPY, 1, (GdkEvent*)event);
+
+		gtk_target_list_unref (target_list);
 	}
 
 	return TRUE;
@@ -672,13 +686,39 @@ button_toggled_cb (GtkWidget *button,
 	if (gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (button)))
 	{
 		GtkWidget *menu;
+		GdkEvent *event;
+		guint32 event_time = 0;
+		guint event_button = 0;
 
 		menu = build_menu (action);
 		g_signal_connect (menu, "deactivate",
 				  G_CALLBACK (menu_deactivate_cb), button);
-		gtk_menu_popup (GTK_MENU (menu), NULL, NULL,
-				ephy_gui_menu_position_under_widget,
-				button, 1, gtk_get_current_event_time ());
+
+		event = gtk_get_current_event ();
+		if (event != NULL)
+		{
+			if (event->type == GDK_BUTTON_PRESS)
+			{
+				event_button = ((GdkEventButton *) event)->button;
+				event_time = ((GdkEventButton *) event)->time;
+			}
+
+			gdk_event_free (event);
+		}
+
+		if (event_button == 0)
+		{
+			gtk_menu_popup (GTK_MENU (menu), NULL, NULL,
+					ephy_gui_menu_position_under_widget,
+					button, 0 , gtk_get_current_event_time ());
+			gtk_menu_shell_select_first (GTK_MENU_SHELL (menu), FALSE);
+		}
+		else
+		{
+			gtk_menu_popup (GTK_MENU (menu), NULL, NULL,
+					ephy_gui_menu_position_under_widget,
+					button, event_button, event_time);
+		}
 
 		g_object_set_data (G_OBJECT (button), "popup", menu);
 	}
@@ -714,7 +754,9 @@ create_menu_item (GtkAction *action)
 }
 
 static void
-show_context_menu (EphyTopicAction *action, GtkWidget *proxy,
+show_context_menu (EphyTopicAction *action,
+		   GtkWidget *proxy,
+		   GdkEventButton *event,
 		   GtkMenuPositionFunc func)
 {
 	GtkWidget *menu, *item;
@@ -722,8 +764,8 @@ show_context_menu (EphyTopicAction *action, GtkWidget *proxy,
 
 	menu = gtk_menu_new ();
 
-	item = add_open_in_tabs_menu (action, menu);
-	gtk_widget_set_sensitive (item, can_open_in_tabs (action));
+	item = add_open_in_tabs_menu (action, menu, action->priv->topic_node);
+	gtk_widget_set_sensitive (item, can_open_in_tabs (action->priv->topic_node));
 
 	item = gtk_separator_menu_item_new ();
 	gtk_widget_show (item);
@@ -754,8 +796,17 @@ show_context_menu (EphyTopicAction *action, GtkWidget *proxy,
 	g_signal_connect (item, "activate",
 			  G_CALLBACK (move_right_activate_cb), proxy);
 
-	gtk_menu_popup (GTK_MENU (menu), NULL, NULL, func, proxy, 3,
-			gtk_get_current_event_time ());
+	if (event != NULL)
+	{
+		gtk_menu_popup (GTK_MENU (menu), NULL, NULL, func, proxy,
+				event->button, event->time);
+	}
+	else
+	{
+		gtk_menu_popup (GTK_MENU (menu), NULL, NULL, func, proxy, 0,
+				gtk_get_current_event_time ());
+		gtk_menu_shell_select_first (GTK_MENU_SHELL (menu), FALSE);
+	}
 }
 
 static gboolean
@@ -763,7 +814,7 @@ popup_menu_cb (GtkWidget *widget, EphyTopicAction *action)
 {
 	if (gtk_widget_get_ancestor (widget, EPHY_TYPE_BOOKMARKSBAR))
         {
-                show_context_menu (action, widget,
+                show_context_menu (action, widget, NULL,
 				   ephy_gui_menu_position_under_widget);
 		return TRUE;
         }
@@ -823,7 +874,7 @@ button_press_cb (GtkWidget *widget,
 	else if (event->button == 3 &&
 	         gtk_widget_get_ancestor (widget, EPHY_TYPE_BOOKMARKSBAR))	
 	{
-		show_context_menu (action, widget, NULL);
+		show_context_menu (action, widget, event, NULL);
 		return TRUE;
 	}
 
