@@ -15,7 +15,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: ephy-topics-selector.c,v 1.24 2004/08/09 10:29:49 chpe Exp $
+ *  $Id: ephy-topics-selector.c,v 1.24.4.1 2004/09/13 10:31:11 chpe Exp $
  */
 
 #ifdef HAVE_CONFIG_H
@@ -215,8 +215,7 @@ topic_destroy_cb (EphyNode *node,
 }
 
 static void
-node_toggled_cb (EphyTopicsSelector *selector, EphyNode *node,
-		 gboolean checked, gpointer data)
+toggle_topic (EphyTopicsSelector *selector, EphyNode *node, gboolean checked)
 {
 	if (selector->priv->bookmark)
 	{
@@ -251,6 +250,13 @@ node_toggled_cb (EphyTopicsSelector *selector, EphyNode *node,
 	}
 }
 
+static void
+node_toggled_cb (EphyTopicsSelector *selector, EphyNode *node,
+		 gboolean checked, gpointer data)
+{
+	toggle_topic (selector, node, checked);
+}
+
 static void
 ephy_topics_selector_init (EphyTopicsSelector *selector)
 {
@@ -309,6 +315,7 @@ ephy_topics_selector_new_topic (EphyTopicsSelector *selector)
 
 	node = ephy_bookmarks_add_keyword
 			(selector->priv->bookmarks, _("Type a topic"));
+	toggle_topic (selector, node, TRUE);
 	ephy_node_view_select_node (EPHY_NODE_VIEW (selector), node);
 	ephy_node_view_edit (EPHY_NODE_VIEW (selector), TRUE);
 }
