@@ -15,7 +15,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: ephy-main.c,v 1.25 2004/08/01 22:16:23 chpe Exp $
+ *  $Id: ephy-main.c,v 1.25.4.1 2004/11/11 12:55:55 chpe Exp $
  */
 
 #ifdef HAVE_CONFIG_H
@@ -83,6 +83,13 @@ shell_weak_notify (gpointer data,
 	gtk_main_quit ();
 }
 
+static gboolean
+idle_unref (GObject *object)
+{
+	g_object_unref (object);
+	return FALSE;
+}
+
 int
 main (int argc, char *argv[])
 {
@@ -185,9 +192,8 @@ main (int argc, char *argv[])
 	}
 	else if (new_instance)
 	{
-		g_object_unref (ephy_shell);
-
 		g_object_weak_ref (G_OBJECT (ephy_shell), shell_weak_notify, NULL);
+		g_idle_add ((GSourceFunc) idle_unref, ephy_shell);
 
 		gtk_main ();
 	}
