@@ -17,7 +17,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: ephy-window.c,v 1.206.4.14 2004/11/07 20:28:22 chpe Exp $
+ *  $Id: ephy-window.c,v 1.206.4.17 2004/12/18 21:03:37 chpe Exp $
  */
 
 #ifdef HAVE_CONFIG_H
@@ -456,6 +456,7 @@ static void
 ephy_window_destroy (GtkObject *gtkobject)
 {
 	EphyWindow *window = EPHY_WINDOW (gtkobject);
+	GSList *popups;
 
 	LOG ("EphyWindow destroy %p", window)
 
@@ -472,6 +473,10 @@ ephy_window_destroy (GtkObject *gtkobject)
 
 	destroy_exit_fullscreen_popup (window);
 
+	popups = gtk_ui_manager_get_toplevels (GTK_UI_MANAGER (window->ui_merge), GTK_UI_MANAGER_POPUP);
+	g_slist_foreach (popups, (GFunc) gtk_menu_shell_deactivate, NULL);
+	g_slist_free (popups);
+
         GTK_OBJECT_CLASS (parent_class)->destroy (gtkobject);
 }
 
@@ -1003,14 +1008,34 @@ update_chromes_actions (EphyWindow *window)
 		 			   window);
 }
 
+static void
+update_print_actions (EphyWindow *window,
+		      gboolean enable)
+{
+	GtkActionGroup *action_group = window->priv->action_group;
+	GtkAction *action;
+	gboolean printing, print_setup;
+
+	printing = !eel_gconf_get_boolean (CONF_LOCKDOWN_DISABLE_PRINTING);
+	print_setup = !eel_gconf_get_boolean (CONF_LOCKDOWN_DISABLE_PRINT_SETUP) &&
+		!eel_gconf_get_boolean (CONF_LOCKDOWN_DISABLE_COMMAND_LINE);
+
+	action = gtk_action_group_get_action (action_group, "FilePrintSetup");
+	g_object_set (action, "sensitive", printing && print_setup, NULL);
+	action = gtk_action_group_get_action (action_group, "FilePrintPreview");
+	g_object_set (action, "sensitive", enable && printing && print_setup, NULL);
+	action = gtk_action_group_get_action (action_group, "FilePrint");
+	g_object_set (action, "sensitive", enable && printing, NULL);
+
+}
+
 static void
 update_actions_sensitivity (EphyWindow *window)
 {
 	GtkActionGroup *action_group = window->priv->action_group;
 	GtkActionGroup *popups_action_group = window->priv->popups_action_group;
 	GtkAction *action;
-	gboolean bookmarks_editable, save_to_disk;
-	gboolean printing, print_setup, fullscreen;
+	gboolean bookmarks_editable, save_to_disk, fullscreen;
 
 	action = gtk_action_group_get_action (action_group, "ViewToolbar");
 	g_object_set (action, "sensitive", eel_gconf_key_is_writable (CONF_WINDOWS_SHOW_TOOLBARS), NULL);
@@ -1048,17 +1073,6 @@ update_actions_sensitivity (EphyWindow *window)
 	g_object_set (action, "sensitive", save_to_disk, NULL);
 	action = gtk_action_group_get_action (popups_action_group, "SaveImageAs");
 	g_object_set (action, "sensitive", save_to_disk, NULL);
-
-	printing = !eel_gconf_get_boolean (CONF_LOCKDOWN_DISABLE_PRINTING);
-	print_setup = !eel_gconf_get_boolean (CONF_LOCKDOWN_DISABLE_PRINT_SETUP) &&
-		!eel_gconf_get_boolean (CONF_LOCKDOWN_DISABLE_COMMAND_LINE);
-	action = gtk_action_group_get_action (action_group, "FilePrintSetup");
-	g_object_set (action, "sensitive", printing && print_setup, NULL);
-	action = gtk_action_group_get_action (action_group, "FilePrintPreview");
-	g_object_set (action, "sensitive", printing && print_setup, NULL);
-	action = gtk_action_group_get_action (action_group, "FilePrint");
-	g_object_set (action, "sensitive", printing, NULL);
-
 	action = gtk_action_group_get_action (popups_action_group, "SetImageAsBackground");
 	g_object_set (action, "sensitive", eel_gconf_key_is_writable (CONF_DESKTOP_BG_PICTURE), NULL);
 
@@ -1072,6 +1086,8 @@ update_actions_sensitivity (EphyWindow *window)
 	g_object_set (action, "sensitive", !fullscreen, NULL);
 	action = gtk_action_group_get_action (action_group, "TabsDetach");
 	g_object_set (action, "sensitive", !fullscreen, NULL);
+
+	update_print_actions (window, TRUE);
 }
 
 static void
@@ -1414,6 +1430,9 @@ sync_tab_load_status (EphyTab *tab, GParamSpec *pspec, EphyWindow *window)
 	status = ephy_tab_get_load_status (tab);
 	g_object_set (action, "sensitive", status, NULL);
 
+	/* disable print while loading, see bug #116344 */
+	update_print_actions (window, !status);
+
 	if (status)
 	{
 		toolbar_spinner_start (window->priv->toolbar);
