@@ -16,7 +16,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: prefs-dialog.c,v 1.85.4.2 2004/11/07 22:58:58 chpe Exp $
+ *  $Id: prefs-dialog.c,v 1.85.4.3 2004/12/19 14:20:42 chpe Exp $
  */
 
 #ifdef HAVE_CONFIG_H
@@ -105,7 +105,7 @@ languages [] =
 	 *                      "Australian English (System setting)"
 	 */ 
 	{ N_("System language"), "system" },
-	{ N_("Afrikaans"), "ak" },
+	{ N_("Afrikaans"), "af" },
 	{ N_("Albanian"), "sq" },
 	{ N_("Arabic"), "ar" },
 	{ N_("Azerbaijani"), "az" },
